@@ -1,6 +1,8 @@
 from django.contrib import admin
 from django.shortcuts import reverse
 from django.utils.safestring import mark_safe
+from django.contrib import messages
+from django.utils.translation import ngettext
 from django_simple_queue.models import Task
 
 
@@ -20,7 +22,17 @@ class TaskAdmin(admin.ModelAdmin):
         ))
     status_page_link.short_description = "Status"
 
-    ordering = ['-created', ]
+    @admin.action(description='Enqueue')
+    def enqueue_tasks(self, request, queryset):
+        updated = queryset.update(status=Task.QUEUED)
+        self.message_user(request, ngettext(
+            '%d task was successfully enqueued.',
+            '%d tasks were successfully enqueued.',
+            updated,
+        ) % updated, messages.SUCCESS)
+
+    ordering = ['-modified', ]
     list_display = ('id', 'created', 'modified', 'task', 'status_page_link')
-    list_filter = ('status', 'created', )
+    list_filter = ('status', 'created', 'modified')
     search_fields = ('id', 'task', 'output')
+    actions = ['enqueue_tasks']
