@@ -1,10 +1,10 @@
 from django.urls import re_path, path
-from taskmanager.views import (
+from django_simple_queue.views import (
     view_task_status,
 )
 
 
-app_name = 'taskmanager'
+app_name = 'django_simple_queue'
 urlpatterns = [
     path('task', view_task_status, name="task"),
 ]
\ No newline at end of file
